==> deepin-deb-installer_1.2.4.orig.tar.gz: deepin-deb-installer-1.2.4/translations/deepin-deb-installer_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Upravitelj paketov Deepin</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Bulk namestitev</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Namestitev ni uspela, prosim preverite vašo omrežno povezavo</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Namestitev ni uspela, prosim preverite posodobitve v Nadzornem centru</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Namestitev ni uspela, ni dovolj prostora na disku</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Namestitev ni uspela</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Okvarjeni odvisni podatki: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Neskladna paketna arhitektura</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Tukaj povlecite in spustite datoteko</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Izberi datoteko</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Skrij</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Prikaži podrobnosti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Namesti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>Nameščam</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Nameščeno</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Ni uspelo</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>Ista različica že nameščena</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>Druga različica nameščena: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Skrij</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Prikaži podrobnosti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Namesti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Ponovno namesti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Uspešno nameščeno</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Uspešno odstranjeno</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>Druga različica nameščena: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Odstranjevanje neuspešno</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>Ista različica že nameščena</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Prikaži podobne pakete</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Skrij</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Res hočete odstraniti %1?
Tudi vsi odvisni podatki bodo odstranjeni</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Upravitelj paketov Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Upravitelj paketov Deepin je aplikacija, ki pomaga uporabnikom namestiti in odstraniti lokalne programe. Podpira bulk namestitev.</translation>
    </message>
</context>
</TS>

==> deepin-deb-installer_1.2.5.orig.tar.gz: deepin-deb-installer-1.2.5/translations/deepin-deb-installer_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Upravitelj paketov Deepin</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Bulk namestitev</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Namestitev ni uspela, prosim preverite vašo omrežno povezavo</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Namestitev ni uspela, prosim preverite posodobitve v Nadzornem centru</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Namestitev ni uspela, ni dovolj prostora na disku</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Namestitev ni uspela</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Okvarjeni odvisni podatki: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Neskladna paketna arhitektura</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Tukaj povlecite in spustite datoteko</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Izberi datoteko</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Skrij</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Prikaži podrobnosti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Namesti</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Opravljeno</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>Nameščam</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Nameščeno</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Ni uspelo</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>Ista različica že nameščena</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>Druga različica nameščena: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Skrij</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Prikaži podrobnosti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Namesti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Ponovno namesti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation>Opravljeno</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Uspešno nameščeno</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Uspešno odstranjeno</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>Druga različica nameščena: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Odstranjevanje neuspešno</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>Ista različica že nameščena</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Prikaži podobne pakete</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Skrij</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Res hočete odstraniti %1?
Tudi vsi odvisni podatki bodo odstranjeni</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Upravitelj paketov Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Upravitelj paketov Deepin je aplikacija, ki pomaga uporabnikom namestiti in odstraniti lokalne programe. Podpira bulk namestitev.</translation>
    </message>
</context>
</TS>
